@@ -4,7 +4,7 @@
 
 from .._constants import _DB_TABLE_NAMES, _PHOTOS_4_VERSION
 from ..sqlite_utils import sqlite_open_ro
-from ..utils import normalize_unicode
+from ..unicode import normalize_unicode
 from .photosdb_utils import get_db_version
 
 """
@@ -179,6 +179,8 @@ def _process_faceinfo_5(photosdb):
     db = photosdb._tmp_db
 
     asset_table = _DB_TABLE_NAMES[photosdb._photos_ver]["ASSET"]
+    asset_fk = _DB_TABLE_NAMES[photosdb._photos_ver]["DETECTED_FACE_ASSET_FK"]
+    person_fk = _DB_TABLE_NAMES[photosdb._photos_ver]["DETECTED_FACE_PERSON_FK"]
 
     (conn, cursor) = sqlite_open_ro(db)
 
@@ -188,7 +190,7 @@ def _process_faceinfo_5(photosdb):
         ZDETECTEDFACE.Z_PK,
         {asset_table}.ZUUID,
         ZDETECTEDFACE.ZUUID,
-        ZDETECTEDFACE.ZPERSON,
+        {person_fk},
         ZPERSON.ZFULLNAME,
         ZDETECTEDFACE.ZAGETYPE,
         NULL, -- ZDETECTEDFACE.ZBALDTYPE (Removed in Monterey)
@@ -225,8 +227,8 @@ def _process_faceinfo_5(photosdb):
         NULL, -- ZDETECTEDFACE.ZYAW,
         ZDETECTEDFACE.ZMASTERIDENTIFIER
         FROM ZDETECTEDFACE
-        JOIN {asset_table} ON {asset_table}.Z_PK = ZDETECTEDFACE.ZASSET
-        JOIN ZPERSON ON ZPERSON.Z_PK = ZDETECTEDFACE.ZPERSON;
+        JOIN {asset_table} ON {asset_table}.Z_PK = {asset_fk}
+        JOIN ZPERSON ON ZPERSON.Z_PK = {person_fk};
         """
     )
 
@@ -309,7 +311,9 @@ def _process_faceinfo_5(photosdb):
         face["righteyey"] = row[34]
         face["roll"] = row[35]
         face["size"] = row[36]
-        face["yaw"] = 0 # Photos 4 only (this is in Photos 5-7, but dropped in Ventura so just don't support it)
+        face[
+            "yaw"
+        ] = 0  # Photos 4 only (this is in Photos 5-7, but dropped in Ventura so just don't support it)
         face["pitch"] = 0  # not defined in Photos 5
 
         photosdb._db_faceinfo_pk[pk] = face
