@@ -1,5 +1,7 @@
 """ Utility functions used in osxphotos """
 
+from __future__ import annotations
+
 import datetime
 import fnmatch
 import hashlib
@@ -9,29 +11,29 @@ import logging
 import os
 import os.path
 import pathlib
-import platform
 import re
 import subprocess
 import sys
-import unicodedata
 import urllib.parse
 from plistlib import load as plistload
-from typing import Callable, List, Optional, Tuple, Union
+from typing import Callable, List, Optional, Tuple, TypeVar, Union
 from uuid import UUID
 
-import CoreFoundation
 import requests
 import shortuuid
 
-from ._constants import UNICODE_FORMAT
+from osxphotos.platform import get_macos_version, is_macos
+from osxphotos.unicode import normalize_fs_path
+
+T = TypeVar("T", bound=Union[str, pathlib.Path])
 
 logger = logging.getLogger("osxphotos")
 
+
 __all__ = [
     "dd_to_dms_str",
     "expand_and_validate_filepath",
     "get_last_library_path",
-    "get_macos_version",
     "get_system_library_path",
     "hexdigest",
     "increment_filename_with_count",
@@ -42,8 +44,6 @@ __all__ = [
     "load_function",
     "lock_filename",
     "noop",
-    "normalize_fs_path",
-    "normalize_unicode",
     "pluralize",
     "shortuuid_to_uuid",
     "uuid_to_shortuuid",
@@ -53,6 +53,10 @@ __all__ = [
 VERSION_INFO_URL = "https://pypi.org/pypi/osxphotos/json"
 
 
+if is_macos:
+    import CoreFoundation
+
+
 def noop(*args, **kwargs):
     """do nothing (no operation)"""
     pass
@@ -66,24 +70,6 @@ def lineno(filename):
     return f"{filename}: {line}"
 
 
-def get_macos_version():
-    # returns tuple of str containing OS version
-    # e.g. 10.13.6 = ("10", "13", "6")
-    version = platform.mac_ver()[0].split(".")
-    if len(version) == 2:
-        (ver, major) = version
-        minor = "0"
-    elif len(version) == 3:
-        (ver, major, minor) = version
-    else:
-        raise (
-            ValueError(
-                f"Could not parse version string: {platform.mac_ver()} {version}"
-            )
-        )
-    return (ver, major, minor)
-
-
 def _check_file_exists(filename):
     """returns true if file exists and is not a directory
     otherwise returns false"""
@@ -164,12 +150,14 @@ def dd_to_dms_str(lat, lon):
 
 def get_system_library_path():
     """return the path to the system Photos library as string"""
-    """ only works on MacOS 10.15 """
+    """ only works on MacOS 10.15+ """
     """ on earlier versions, returns None """
-    _, major, _ = get_macos_version()
-    if int(major) < 15:
+    if not is_macos:
+        return None
+    ver, major, minor = get_macos_version()
+    if (int(ver), int(major)) < (10, 15):
         logger.debug(
-            f"get_system_library_path not implemented for MacOS < 10.15: you have {major}"
+            f"get_system_library_path not implemented for MacOS < 10.15: you have {ver}.{major}.{minor}"
         )
         return None
 
@@ -241,6 +229,8 @@ def get_last_library_path():
 def list_photo_libraries():
     """returns list of Photos libraries found on the system"""
     """ on MacOS < 10.15, this may omit some libraries """
+    if not is_macos:
+        return []
 
     # On 10.15, mdfind appears to find all libraries
     # On older MacOS versions, mdfind appears to ignore some libraries
@@ -263,13 +253,6 @@ def list_photo_libraries():
     return lib_list
 
 
-def normalize_fs_path(path: str) -> str:
-    """Normalize filesystem paths with unicode in them"""
-    # macOS HFS+ uses NFD, APFS doesn't normalize but stick with NFD
-    # ref: https://eclecticlight.co/2021/05/08/explainer-unicode-normalization-and-apfs/
-    return unicodedata.normalize("NFD", path)
-
-
 # def findfiles(pattern, path):
 #     """Returns list of filenames from path matched by pattern
 #     shell pattern. Matching is case-insensitive.
@@ -356,18 +339,6 @@ def list_directory(
     return files
 
 
-def normalize_unicode(value):
-    """normalize unicode data"""
-    if value is None:
-        return None
-    if isinstance(value, (tuple, list)):
-        return tuple(unicodedata.normalize(UNICODE_FORMAT, v) for v in value)
-    elif isinstance(value, str):
-        return unicodedata.normalize(UNICODE_FORMAT, value)
-    else:
-        return value
-
-
 def increment_filename_with_count(
     filepath: Union[str, pathlib.Path], count: int = 0, lock: bool = False
 ) -> Tuple[str, int]:
@@ -432,7 +403,9 @@ def lock_filename(filepath: Union[str, pathlib.Path]) -> bool:
     Returns:
         filepath if lock file created, False if lock file already exists
     """
+    return filepath
 
+    # TODO: for future implementation
     lockfile = pathlib.Path(f"{filepath}.osxphotos.lock")
     if lockfile.exists():
         return False
@@ -447,6 +420,9 @@ def unlock_filename(filepath: Union[str, pathlib.Path]):
         filepath: str or pathlib.Path; full path, including file name
     """
 
+    return
+
+    # TODO: for future implementation
     lockfile = pathlib.Path(f"{filepath}.osxphotos.lock")
     if lockfile.exists():
         lockfile.unlink()
@@ -539,6 +515,7 @@ def shortuuid_to_uuid(short_uuid: str) -> str:
     """Convert shortuuid to uuid"""
     return str(shortuuid.decode(short_uuid)).upper()
 
+
 def under_test() -> bool:
     """Return True if running under pytest"""
-    return "pytest" in sys.modules
\ No newline at end of file
+    return "pytest" in sys.modules
